Improve dynamic audio resampler filter generation

Improve dynamic audio resampler filter generation speed by 2x.
The resulting filters should be the same (excepting roundoff).

Also added check for upsampling sample rate changes to share
previously generated filters.

Modify the profiling to improve output format and sampling result
reliability.

Change-Id: I9aa6b914fd552a63f79dd4a95945df2f8275772a
Signed-off-by: Andy Hung <hunga@google.com>
diff --git a/services/audioflinger/AudioResamplerDyn.h b/services/audioflinger/AudioResamplerDyn.h
index 85a01ab..df1fdbe 100644
--- a/services/audioflinger/AudioResamplerDyn.h
+++ b/services/audioflinger/AudioResamplerDyn.h
@@ -113,7 +113,8 @@
     Constants mConstants;  // current set of coefficient parameters
     int32_t __attribute__ ((aligned (8))) mVolumeSimd[2];
     int32_t mResampleType; // contains the resample type.
-    int32_t mFilterSampleRate; // designed sample rate for the filter
+    int32_t mFilterSampleRate; // designed filter sample rate.
+    src_quality mFilterQuality; // designed filter quality.
     void* mCoefBuffer; // if a filter is created, this is not null
 };